@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from mootdx import config
 from mootdx.consts import EX_HOSTS
 from mootdx.consts import GP_HOSTS
@@ -6,7 +5,7 @@ from mootdx.consts import HQ_HOSTS
 from mootdx.server import Server
 from mootdx.utils import get_config_path
 
-__version__ = '0.7.16'
-__author__ = "bopo.wang<ibopo@126.com>"
+__version__ = '0.7.18'
+__author__ = 'bopo.wang<ibopo@126.com>'
 
 config.setup()
