@@ -1,21 +1,20 @@
-# -*- coding: utf-8 -*-
 import os
 import random
 import shutil
 import tempfile
-from abc import ABC
+from pathlib import Path
 from struct import calcsize
 from struct import unpack
 
 import pandas as pd
 from pytdx.hq import TdxHq_API
-from unipath import Path
 
+from ..logger import log
+from ..logger import logger
 from .base import BaseFinancial
-from .base import BaseReader
 
 
-class FinancialReader(BaseReader, ABC):
+class FinancialReader(object):
     @staticmethod
     def to_data(filename):
         """
@@ -27,9 +26,11 @@ class FinancialReader(BaseReader, ABC):
         :return: pandas DataFrame 格式的历史财务数据
         """
 
+        print(filename)
+
         crawler = Financial()
 
-        with open(filename, "rb") as fp:
+        with open(filename, 'rb') as fp:
             data = crawler.parse(download_file=fp)
 
         return crawler.to_df(data)
@@ -44,17 +45,9 @@ class FinancialList(BaseFinancial):
         :param kwargs:
         :return:
         """
-        return "https://gitee.com/yutiansut/QADATA/raw/master/financial/content.txt"
+        return 'https://gitee.com/yutiansut/QADATA/raw/master/financial/content.txt'
 
-    def content(
-        self,
-        report_hook=None,
-        downdir=None,
-        proxies=None,
-        chunk_size=1024 * 50,
-        *args,
-        **kwargs,
-    ):
+    def content(self, report_hook=None, downdir=None, proxies=None, chunk_size=1024 * 50, *args, **kwargs):
         """
         解析财务文件
 
@@ -67,16 +60,14 @@ class FinancialList(BaseFinancial):
         :return:
         """
 
+        tmp = tempfile.NamedTemporaryFile(delete=True)
+
         api = TdxHq_API(**kwargs)
         api.need_setup = False
 
         with api.connect(*self.bestip):
-            content = api.get_report_file_by_size("tdxfin/gpcw.txt")
-            download_file = (
-                open(downdir, "wb")
-                if downdir
-                else tempfile.NamedTemporaryFile(delete=True)
-            )
+            content = api.get_report_file_by_size('tdxfin/gpcw.txt')
+            download_file = (open(downdir, 'wb') if downdir else tmp)
             download_file.write(content)
             download_file.seek(0)
 
@@ -94,24 +85,20 @@ class FinancialList(BaseFinancial):
 
         with download_file:
             content = download_file.read()
-            content = content.decode("utf-8")
+            content = content.decode('utf-8')
 
-        def list_to_dict(i):
-            return {"filename": i[0], "hash": i[1], "filesize": int(i[2])}
+        def l2d(i):
+            return {'filename': i[0], 'hash': i[1], 'filesize': int(i[2])}
 
         if content:
-            return [
-                list_to_dict(i)
-                for i in [
-                    line.strip().split(",") for line in content.strip().split("\n")
-                ]
-            ]
+            content = content.strip().split('\n')
+            return [l2d(i) for i in [line.strip().split(',') for line in content]]
 
         return None
 
 
 class Financial(BaseFinancial):
-    mode = "content"
+    mode = 'content'
 
     def build_url(self, *args, **kwargs):
         """
@@ -121,22 +108,14 @@ class Financial(BaseFinancial):
         :param kwargs:
         :return:
         """
-        filename = kwargs.get("filename")
+        filename = kwargs.get('filename')
 
         if not filename:
-            raise Exception("Param filename is not set")
+            raise Exception('Param filename is not set')
 
-        return f"http://down.tdx.com.cn:8001/fin/{filename}"
+        return f'http://down.tdx.com.cn:8001/fin/{filename}'
 
-    def content(
-        self,
-        report_hook=None,
-        downdir=None,
-        proxies=None,
-        chunk_size=1024 * 50,
-        *args,
-        **kwargs,
-    ):
+    def content(self, report_hook=None, downdir=None, proxies=None, chunk_size=1024 * 50, *args, **kwargs):
         """
         解析财务文件
 
@@ -149,29 +128,28 @@ class Financial(BaseFinancial):
         :return:
         """
 
-        filename = kwargs.get("filename")
-        filesize = kwargs.get("filesize") if kwargs.get("filesize") else 0
+        filename = kwargs.get('filename')
+        downfile = str(Path(downdir) / filename)
+        filesize = kwargs.get('filesize') if kwargs.get('filesize') else 0
+
+        log.info('{}: start download...', filename)
 
         if not filename:
-            raise Exception("Param filename is not set")
+            raise Exception('Param filename is not set')
 
         api = TdxHq_API()
         api.need_setup = False
 
         with api.connect(*self.bestip):
-            content = api.get_report_file_by_size(
-                f"tdxfin/{filename}", filesize=filesize, reporthook=report_hook
-            )
-            download_file = (
-                open(downdir, "wb")
-                if downdir
-                else tempfile.NamedTemporaryFile(delete=True)
-            )
+            content = api.get_report_file_by_size(f'tdxfin/{filename}', filesize=filesize, reporthook=report_hook)
+            download_file = (open(downfile, 'wb') if downfile else tempfile.NamedTemporaryFile(delete=True))
             download_file.write(content)
             download_file.seek(0)
 
             del content
 
+            log.info('{}: done', filename)
+
             return download_file
 
     def parse(self, download_file, *args, **kwargs):
@@ -184,13 +162,13 @@ class Financial(BaseFinancial):
         :return:
         """
 
-        header_pack_format = "<1hI1H3L"
+        header_pack_format = '<1hI1H3L'
         tmpdir = tempfile.gettempdir()
 
-        if download_file.name.endswith(".zip"):
+        if download_file.name.endswith('.zip'):
             tmpdir_root = tempfile.gettempdir()
             random_sums = str(random.randint(0, 1000000))
-            subdir_name = f"mootdx_{random_sums}"
+            subdir_name = f'mootdx_{random_sums}'
 
             tmpdir = Path(tmpdir_root, subdir_name)
             shutil.rmtree(tmpdir, ignore_errors=True)
@@ -202,19 +180,19 @@ class Financial(BaseFinancial):
             datfile = None
 
             for _file in os.listdir(tmpdir):
-                if _file.endswith(".dat"):
-                    datfile = open(Path(tmpdir, _file), "rb")
+                if _file.endswith('.dat'):
+                    datfile = open(Path(tmpdir, _file), 'rb')
 
             if datfile is None:
-                raise Exception("no dat file found in zip archive")
+                raise Exception('no dat file found in zip archive')
 
-        elif download_file.name.endswith(".dat"):
+        elif download_file.name.endswith('.dat'):
             datfile = download_file
         else:
             return None
 
         header_size = calcsize(header_pack_format)
-        stock_item_size = calcsize("<6s1c1L")
+        stock_item_size = calcsize('<6s1c1L')
         data_header = datfile.read(header_size)
         stock_header = unpack(header_pack_format, data_header)
 
@@ -224,15 +202,15 @@ class Financial(BaseFinancial):
         report_size = stock_header[4]
 
         report_fields_count = int(report_size / 4)
-        report_pack_format = "<{}f".format(report_fields_count)
+        report_pack_format = '<{}f'.format(report_fields_count)
 
         results = []
 
         for stock_idx in range(0, max_count):
-            datfile.seek(header_size + stock_idx * calcsize("<6s1c1L"))
+            datfile.seek(header_size + stock_idx * calcsize('<6s1c1L'))
             si = datfile.read(stock_item_size)
-            stock_item = unpack("<6s1c1L", si)
-            code = stock_item[0].decode("utf-8")
+            stock_item = unpack('<6s1c1L', si)
+            code = stock_item[0].decode('utf-8')
             foa = stock_item[2]
             datfile.seek(foa)
 
@@ -241,7 +219,7 @@ class Financial(BaseFinancial):
             one_record = (code, report_date) + cw_info
             results.append(one_record)
 
-        if download_file.name.endswith(".zip"):
+        if download_file.name.endswith('.zip'):
             datfile.close()
             shutil.rmtree(tmpdir, ignore_errors=True)
 
@@ -261,12 +239,14 @@ class Financial(BaseFinancial):
             return None
 
         length = len(data[0]) - 1
-        column = ["code", "report_date"]
+        column = ['code', 'report_date']
 
         for i in range(1, length):
-            column.append("col" + str(i))
+            column.append('col' + str(i))
 
         df = pd.DataFrame(data=data, columns=column)
-        df.set_index("code", inplace=True)
+        df.set_index('code', inplace=True)
+
+        logger.debug(df)
 
         return df
