@@ -1,5 +1,5 @@
-# -*- coding: utf-8 -*-
 import math
+from pathlib import Path
 
 import pandas
 import pandas as pd
@@ -10,7 +10,6 @@ from tenacity import retry_if_exception_type
 from tenacity import retry_if_result
 from tenacity import stop_after_attempt
 from tqdm import tqdm
-from unipath import Path
 
 from mootdx import config
 from mootdx import server
@@ -24,7 +23,7 @@ from mootdx.utils import to_data
 
 class Quotes(object):
     @staticmethod
-    def factory(market="std", **kwargs):
+    def factory(market='std', **kwargs):
         """
         股票市场 工厂方法
 
@@ -32,9 +31,9 @@ class Quotes(object):
         :param kwargs:
         :return: object
         """
-        if market == "ext":
+        if market == 'ext':
             return ExtQuotes(**kwargs)
-        elif market == "std":
+        elif market == 'std':
             return StdQuotes(**kwargs)
 
 
@@ -43,37 +42,35 @@ class BaseQuotes(object):
     bestip = None
 
     def __init__(self, bestip=False, timeout=15, **kwargs):
-        log.debug(f"bestip=>{bestip}")
+        log.debug(f'bestip=>{bestip}')
 
         self.timeout = timeout
 
-        Path(get_config_path("config.json")).exists() or server.bestip()
+        Path(get_config_path('config.json')).exists() or server.bestip()
 
     def __del__(self):
-        log.debug("__del__")
+        log.debug('__del__')
         self.close()
 
     def reconnect(self):
         if self.closed:
-            log.debug("服务器连接已断开，正进行重新连接...")
+            log.debug('服务器连接已断开，正进行重新连接...')
             self.client.connect(time_out=self.timeout, *self.bestip)
             # self.client.connect(*self.bestip)
 
     def close(self):
-        log.debug("close")
+        log.debug('close')
         self.client.close()
 
     @property
     def closed(self):
-        if not hasattr(self.client.client, "_closed") or getattr(
-            self.client.client, "_closed"
-        ):
+        if not hasattr(self.client.client, '_closed') or getattr(self.client.client, '_closed'):
             return True
 
         return False
 
 
-instance: BaseQuotes = None
+instance: BaseQuotes
 
 
 def is_empty(value):
@@ -81,9 +78,10 @@ def is_empty(value):
 
     status = value.all().empty if isinstance(value, pd.DataFrame) else not value
 
-    print("is_empty is ", status)
+    log.debug('is_empty is ', status)
 
     if instance and status:
+        log.debug("重新连接 {}:{}", instance.bestip, instance.timeout)
         instance.client.connect(time_out=instance.timeout, *instance.bestip)
 
     return status
@@ -100,12 +98,12 @@ class StdQuotes(BaseQuotes):
         super(StdQuotes, self).__init__(bestip=bestip, timeout=timeout, **kwargs)
 
         try:
-            config.get("SERVER").get("HQ")[0]
+            config.get('SERVER').get('HQ')[0]
         except ValueError:
             server.bestip()
         finally:
-            default = config.get("SERVER").get("HQ")[0]
-            self.bestip = config.get("BESTIP").get("HQ", default)
+            default = config.get('SERVER').get('HQ')[0]
+            self.bestip = config.get('BESTIP').get('HQ', default)
 
         self.client = TdxHq_API(raise_exception=False, **kwargs)
         self.client.connect(*self.bestip)
@@ -113,17 +111,11 @@ class StdQuotes(BaseQuotes):
         global instance
         instance = self
 
-    @retry(
-        stop=stop_after_attempt(3),
-        retry=(retry_if_exception_type() | retry_if_result(is_empty)),
-    )
+    @retry(stop=stop_after_attempt(3), retry=(retry_if_exception_type() | retry_if_result(is_empty)))
     def traffic(self):
         return self.client.get_traffic_stats()
 
-    @retry(
-        stop=stop_after_attempt(3),
-        retry=(retry_if_exception_type() | retry_if_result(is_empty)),
-    )
+    @retry(stop=stop_after_attempt(3), retry=(retry_if_exception_type() | retry_if_result(is_empty)))
     def quotes(self, symbol=None):
         """
         获取实时日行情数据
@@ -143,11 +135,8 @@ class StdQuotes(BaseQuotes):
 
         return to_data(result)
 
-    @retry(
-        stop=stop_after_attempt(3),
-        retry=(retry_if_exception_type() | retry_if_result(is_empty)),
-    )
-    def bars(self, symbol="000001", frequency=9, start=0, offset=100, *args, **kwargs):
+    @retry(stop=stop_after_attempt(3), retry=(retry_if_exception_type() | retry_if_result(is_empty)))
+    def bars(self, symbol='000001', frequency=9, start=0, offset=100):
         """
         获取实时日K线数据
 
@@ -166,11 +155,8 @@ class StdQuotes(BaseQuotes):
 
         return to_data(result)
 
-    @retry(
-        stop=stop_after_attempt(3),
-        retry=(retry_if_exception_type() | retry_if_result(is_empty)),
-    )
-    def stock_count(self, market=MARKET_SH, *args, **kwargs):
+    @retry(stop=stop_after_attempt(3), retry=(retry_if_exception_type() | retry_if_result(is_empty)))
+    def stock_count(self, market=MARKET_SH):
         """
         获取市场股票数量
 
@@ -182,11 +168,8 @@ class StdQuotes(BaseQuotes):
 
         return result
 
-    @retry(
-        stop=stop_after_attempt(3),
-        retry=(retry_if_exception_type() | retry_if_result(is_empty)),
-    )
-    def stocks(self, market=MARKET_SH, *args, **kwargs):
+    @retry(stop=stop_after_attempt(3), retry=(retry_if_exception_type() | retry_if_result(is_empty)))
+    def stocks(self, market=MARKET_SH):
         """
         获取股票列表
 
@@ -207,13 +190,8 @@ class StdQuotes(BaseQuotes):
 
         return stocks
 
-    @retry(
-        stop=stop_after_attempt(3),
-        retry=(retry_if_exception_type() | retry_if_result(is_empty)),
-    )
-    def index_bars(
-        self, symbol="000001", frequency=9, start=0, offset=100, *args, **kwargs
-    ):
+    @retry(stop=stop_after_attempt(3), retry=(retry_if_exception_type() | retry_if_result(is_empty)))
+    def index_bars(self, symbol='000001', frequency=9, start=0, offset=100):
         """
         获取指数k线
 
@@ -225,17 +203,12 @@ class StdQuotes(BaseQuotes):
         """
 
         market = get_stock_market(symbol)
-        result = self.client.get_index_bars(
-            frequency=frequency, market=market, code=symbol, start=start, count=offset
-        )
+        result = self.client.get_index_bars(frequency=frequency, market=market, code=symbol, start=start, count=offset)
 
         return to_data(result)
 
-    @retry(
-        stop=stop_after_attempt(3),
-        retry=(retry_if_exception_type() | retry_if_result(is_empty)),
-    )
-    def minute(self, symbol=""):
+    @retry(stop=stop_after_attempt(3), retry=(retry_if_exception_type() | retry_if_result(is_empty)))
+    def minute(self, symbol=''):
         """
         获取实时分时数据
 
@@ -248,11 +221,8 @@ class StdQuotes(BaseQuotes):
 
         return to_data(result)
 
-    @retry(
-        stop=stop_after_attempt(3),
-        retry=(retry_if_exception_type() | retry_if_result(is_empty)),
-    )
-    def minutes(self, symbol="", date="20191023", *args, **kwargs):
+    @retry(stop=stop_after_attempt(3), retry=(retry_if_exception_type() | retry_if_result(is_empty)))
+    def minutes(self, symbol='', date='20191023'):
         """
         分时历史数据
 
@@ -262,17 +232,12 @@ class StdQuotes(BaseQuotes):
         """
 
         market = get_stock_market(symbol)
-        result = self.client.get_history_minute_time_data(
-            market=market, code=symbol, date=date
-        )
+        result = self.client.get_history_minute_time_data(market=market, code=symbol, date=date)
 
         return to_data(result)
 
-    @retry(
-        stop=stop_after_attempt(3),
-        retry=(retry_if_exception_type() | retry_if_result(is_empty)),
-    )
-    def transaction(self, symbol="", start=0, offset=10, *args, **kwargs):
+    @retry(stop=stop_after_attempt(3), retry=(retry_if_exception_type() | retry_if_result(is_empty)))
+    def transaction(self, symbol='', start=0, offset=10):
         """
         查询分笔成交
 
@@ -287,11 +252,8 @@ class StdQuotes(BaseQuotes):
 
         return to_data(result)
 
-    @retry(
-        stop=stop_after_attempt(3),
-        retry=(retry_if_exception_type() | retry_if_result(is_empty)),
-    )
-    def transactions(self, symbol="", start=0, offset=10, date="20170209"):
+    @retry(stop=stop_after_attempt(3), retry=(retry_if_exception_type() | retry_if_result(is_empty)))
+    def transactions(self, symbol='', start=0, offset=10, date='20170209'):
         """
         查询历史分笔成交
         参数：市场代码， 股票代码，起始位置，日期 数量 如： 0,000001,0,10,20170209
@@ -310,11 +272,8 @@ class StdQuotes(BaseQuotes):
 
         return to_data(result)
 
-    @retry(
-        stop=stop_after_attempt(3),
-        retry=(retry_if_exception_type() | retry_if_result(is_empty)),
-    )
-    def F10C(self, symbol=""):
+    @retry(stop=stop_after_attempt(3), retry=(retry_if_exception_type() | retry_if_result(is_empty)))
+    def F10C(self, symbol=''):
         """
         查询公司信息目录
 
@@ -326,11 +285,8 @@ class StdQuotes(BaseQuotes):
 
         return result
 
-    @retry(
-        stop=stop_after_attempt(3),
-        retry=(retry_if_exception_type() | retry_if_result(is_empty)),
-    )
-    def F10(self, symbol="", name=""):
+    @retry(stop=stop_after_attempt(3), retry=(retry_if_exception_type() | retry_if_result(is_empty)))
+    def F10(self, symbol='', name=''):
         """
         读取公司信息详情
 
@@ -348,31 +304,28 @@ class StdQuotes(BaseQuotes):
 
         if name:
             for x in frequency:
-                if x["name"] == name:
+                if x['name'] == name:
                     return self.client.get_company_info_content(
                         market=market,
                         code=symbol,
-                        filename=x["filename"],
-                        start=x["start"],
-                        length=x["length"],
+                        filename=x['filename'],
+                        start=x['start'],
+                        length=x['length'],
                     )
 
         for x in frequency:
-            result[x["name"]] = self.client.get_company_info_content(
+            result[x['name']] = self.client.get_company_info_content(
                 market=market,
                 code=symbol,
-                filename=x["filename"],
-                start=x["start"],
-                length=x["length"],
+                filename=x['filename'],
+                start=x['start'],
+                length=x['length'],
             )
 
         return result
 
-    @retry(
-        stop=stop_after_attempt(3),
-        retry=(retry_if_exception_type() | retry_if_result(is_empty)),
-    )
-    def xdxr(self, symbol=""):
+    @retry(stop=stop_after_attempt(3), retry=(retry_if_exception_type() | retry_if_result(is_empty)))
+    def xdxr(self, symbol=''):
         """
         读取除权除息信息
 
@@ -385,11 +338,8 @@ class StdQuotes(BaseQuotes):
 
         return to_data(result)
 
-    @retry(
-        stop=stop_after_attempt(3),
-        retry=(retry_if_exception_type() | retry_if_result(is_empty)),
-    )
-    def finance(self, symbol="000001"):
+    @retry(stop=stop_after_attempt(3), retry=(retry_if_exception_type() | retry_if_result(is_empty)))
+    def finance(self, symbol='000001'):
         """
         读取财务信息
 
@@ -402,11 +352,8 @@ class StdQuotes(BaseQuotes):
 
         return to_data(result)
 
-    @retry(
-        stop=stop_after_attempt(3),
-        retry=(retry_if_exception_type() | retry_if_result(is_empty)),
-    )
-    def k(self, symbol="", begin=None, end=None):
+    @retry(stop=stop_after_attempt(3), retry=(retry_if_exception_type() | retry_if_result(is_empty)))
+    def k(self, symbol='', begin=None, end=None):
         """
         读取k线信息
 
@@ -419,11 +366,8 @@ class StdQuotes(BaseQuotes):
         result = self.client.get_k_data(symbol, begin, end)
         return result
 
-    @retry(
-        stop=stop_after_attempt(3),
-        retry=(retry_if_exception_type() | retry_if_result(is_empty)),
-    )
-    def index(self, symbol="000001", market=MARKET_SH, frequency=9, start=1, offset=2):
+    @retry(stop=stop_after_attempt(3), retry=(retry_if_exception_type() | retry_if_result(is_empty)))
+    def index(self, symbol='000001', market=MARKET_SH, frequency=9, start=1, offset=2):
         """
         获取指数k线
 
@@ -455,11 +399,8 @@ class StdQuotes(BaseQuotes):
         )
         return to_data(result)
 
-    @retry(
-        stop=stop_after_attempt(3),
-        retry=(retry_if_exception_type() | retry_if_result(is_empty)),
-    )
-    def block(self, tofile="block.dat"):
+    @retry(stop=stop_after_attempt(3), retry=(retry_if_exception_type() | retry_if_result(is_empty)))
+    def block(self, tofile='block.dat'):
         """
         获取证券板块信息
 
@@ -476,18 +417,18 @@ class ExtQuotes(BaseQuotes):
     扩展市场实时行情
     """
 
-    bestip = ("112.74.214.43", 7727)
+    bestip = ('112.74.214.43', 7727)
 
     def __init__(self, bestip=False, timeout=15, **kwargs):
         super(ExtQuotes, self).__init__(bestip=bestip, timeout=timeout, **kwargs)
 
         try:
-            config.get("SERVER").get("EX")[0]
+            config.get('SERVER').get('EX')[0]
         except ValueError:
             server.bestip()
         finally:
-            default = config.get("SERVER").get("EX")[0]
-            self.bestip = config.get("BESTIP").get("EX", default)
+            default = config.get('SERVER').get('EX')[0]
+            self.bestip = config.get('BESTIP').get('EX', default)
 
         self.client = TdxExHq_API(**kwargs)
         self.client.connect(*self.bestip)
@@ -495,12 +436,12 @@ class ExtQuotes(BaseQuotes):
     @staticmethod
     def validate(market, symbol):
         if not market:
-            if len(symbol.split("#")) > 1:
-                market = symbol.split("#")[0]
-                symbol = symbol.split("#")[1]
+            if len(symbol.split('#')) > 1:
+                market = symbol.split('#')[0]
+                symbol = symbol.split('#')[1]
 
         if not market:
-            raise ValueError("市场参数错误, 市场参数不能为空.")
+            raise ValueError('市场参数错误, 市场参数不能为空.')
 
         return int(market), symbol
 
@@ -554,7 +495,7 @@ class ExtQuotes(BaseQuotes):
 
         return to_data(result)
 
-    def quote(self, market="", symbol=""):
+    def quote(self, market='', symbol=''):
         """
         查询五档行情
 
@@ -568,7 +509,7 @@ class ExtQuotes(BaseQuotes):
 
         return to_data(result)
 
-    def minute(self, market="", symbol=""):
+    def minute(self, market='', symbol=''):
         """
         查询分时行情
 
@@ -582,7 +523,7 @@ class ExtQuotes(BaseQuotes):
 
         return to_data(result)
 
-    def minutes(self, market=None, symbol="", date=""):
+    def minutes(self, market=None, symbol='', date=''):
         """
         查询历史分时行情
 
@@ -597,7 +538,7 @@ class ExtQuotes(BaseQuotes):
 
         return to_data(result)
 
-    def bars(self, frequency="", market="", symbol="", start=0, offset=100):
+    def bars(self, frequency='', market='', symbol='', start=0, offset=100):
         """
         查询k线数据
         参数： K线周期， 市场ID， 证券代码，起始位置， 数量
@@ -617,7 +558,7 @@ class ExtQuotes(BaseQuotes):
 
         return to_data(result)
 
-    def transaction(self, market=None, symbol="", start=0, offset=1800):
+    def transaction(self, market=None, symbol='', start=0, offset=1800):
         """
         查询分笔成交
 
@@ -635,7 +576,7 @@ class ExtQuotes(BaseQuotes):
 
         return to_data(result)
 
-    def transactions(self, market=None, symbol="", date="", start=0, offset=1800):
+    def transactions(self, market=None, symbol='', date='', start=0, offset=1800):
         """
         查询历史分笔成交
 
