@@ -1,11 +1,11 @@
-# -*- coding: utf-8 -*-
 from abc import ABC
+from pathlib import Path
 
-from pytdx.reader import (BlockReader, TdxMinBarReader)
+from pytdx.reader import BlockReader
 from pytdx.reader import CustomerBlockReader
 from pytdx.reader import TdxExHqDailyBarReader
 from pytdx.reader import TdxLCMinBarReader
-from unipath import Path
+from pytdx.reader import TdxMinBarReader
 
 from mootdx import utils
 from mootdx.consts import TYPE_GROUP
@@ -17,7 +17,7 @@ from mootdx.utils import get_stock_market
 # 股票市场
 class Reader(object):
     @staticmethod
-    def factory(market="std", **kwargs):
+    def factory(market='std', **kwargs):
         """
         Reader 工厂方法
 
@@ -25,9 +25,9 @@ class Reader(object):
         :param kwargs:
         :return:
         """
-        if market == "ext":
+        if market == 'ext':
             return ExtReader(**kwargs)
-        elif market == "std":
+        elif market == 'std':
             return StdReader(**kwargs)
 
 
@@ -35,7 +35,7 @@ class ReaderBase(ABC):
     """股票市场"""
 
     # 默认通达信安装目录
-    tdxdir = "C:/new_tdx"
+    tdxdir = 'C:/new_tdx'
 
     def __init__(self, tdxdir=None):
         """
@@ -44,13 +44,13 @@ class ReaderBase(ABC):
         :param tdxdir: 通达信安装目录
         """
 
-        if not Path(tdxdir).isdir():
-            log.error("tdxdir 目录不存在")
-            raise Exception("tdxdir 目录不存在")
+        if not Path(tdxdir).is_dir():
+            log.error('tdxdir 目录不存在')
+            raise Exception('tdxdir 目录不存在')
 
         self.tdxdir = tdxdir
 
-    def find_path(self, symbol=None, subdir="lday", suffix=None):
+    def find_path(self, symbol=None, subdir='lday', suffix=None):
         """
         自动匹配文件路径，辅助函数
 
@@ -59,21 +59,19 @@ class ReaderBase(ABC):
         :param suffix:
         :return: pd.dataFrame or None
         """
-        market = get_stock_market(symbol, True) if len(symbol.split("#")) == 1 else "ds"
-        prefix = market if len(symbol.split("#")) == 1 else ""
+        market = get_stock_market(symbol, True) if len(symbol.split('#')) == 1 else 'ds'
+        prefix = market if len(symbol.split('#')) == 1 else ''
         suffix = suffix if isinstance(suffix, list) else [suffix]
 
         for ex_ in suffix:
-            ex_ = ex_.strip(".")
-            vipdoc = Path(
-                self.tdxdir, "vipdoc", market, subdir, f"{prefix}{symbol}.{ex_}"
-            )
+            ex_ = ex_.strip('.')
+            vipdoc = Path(self.tdxdir) / 'vipdoc' / market / subdir / f'{prefix}{symbol}.{ex_}'
 
             if not Path(vipdoc).exists():
-                log.debug(f"未找到所需的文件: {vipdoc}")
+                log.warning(f'未找到所需的文件: {vipdoc}')
                 continue
 
-            log.debug(f"找到所需的文件: {vipdoc}")
+            log.warning(f'找到所需的文件: {vipdoc}')
 
             return vipdoc
 
@@ -91,10 +89,11 @@ class StdReader(ReaderBase):
         :return: pd.dataFrame or None
         """
         reader = MooTdxDailyBarReader()
-        vipdoc = self.find_path(symbol=symbol, subdir="lday", suffix="day")
+        vipdoc = self.find_path(symbol=symbol, subdir='lday', suffix='day')
 
-        if vipdoc is not None:
-            return reader.get_df(vipdoc)
+        if vipdoc:
+            log.error(str(vipdoc))
+            return reader.get_df(str(vipdoc))
 
         return None
 
@@ -106,13 +105,15 @@ class StdReader(ReaderBase):
         :param symbol:
         :return: pd.dataFrame or None
         """
-        subdir = "fzline" if str(suffix) == "5" else "minline"
-        suffix = ["lc5", "5"] if str(suffix) == "5" else ["lc1", "1"]
+        subdir = 'fzline' if str(suffix) == '5' else 'minline'
+        suffix = ['lc5', '5'] if str(suffix) == '5' else ['lc1', '1']
         symbol = self.find_path(symbol, subdir=subdir, suffix=suffix)
 
         if symbol is not None:
-            reader = TdxMinBarReader() if 'lc' not in symbol.ext else TdxLCMinBarReader()
-            return reader.get_df(symbol)
+            reader = (
+                TdxMinBarReader() if 'lc' not in symbol.suffix else TdxLCMinBarReader()
+            )
+            return reader.get_df(str(symbol))
 
         return None
 
@@ -137,23 +138,25 @@ class StdReader(ReaderBase):
         :return: pd.dataFrame or Bool
         """
 
-        if name or symbol:
+        if name and symbol:
             return utils.block_new(self.tdxdir, name=name, symbol=symbol)
 
         reader = CustomerBlockReader()
-        vipdoc = Path(self.tdxdir, "T0002", "blocknew")
+        vipdoc = Path(self.tdxdir, 'T0002', 'blocknew')
+
+        Path(vipdoc).is_dir() or Path(vipdoc).mkdir(parents=True)
 
         fmt = TYPE_GROUP if group else None
 
-        if Path(vipdoc).isdir():
-            log.debug(f"找到所需的文件: {vipdoc}")
-            return reader.get_df(vipdoc, fmt)
+        if Path(vipdoc).is_dir():
+            log.debug(f'找到所需的文件: {vipdoc}')
+            return reader.get_df(str(vipdoc), fmt)
 
-        log.error(f"未找到所需的文件: {vipdoc}")
+        log.error(f'未找到所需的文件: {vipdoc}')
 
         return None
 
-    def block(self, symbol="", group=False):
+    def block(self, symbol='', group=False):
         """
         获取板块数据
         参考: http://blog.sina.com.cn/s/blog_623d2d280102vt8y.html
@@ -163,20 +166,21 @@ class StdReader(ReaderBase):
         :return: pd.dataFrame or None
         """
 
-        suffix = symbol.split(".")
-        suffix = suffix[-1] if len(suffix) > 1 else "dat"
+        suffix = symbol.split('.')
+        suffix = suffix[-1] if len(suffix) > 1 else 'dat'
         symbol = suffix[0]
         # suffix = 'dat'
 
         reader = BlockReader()
-        vipdoc = Path(self.tdxdir, "T0002", "hq_cache", f"{symbol}.{suffix}")
+        vipdoc = Path(self.tdxdir, 'T0002', 'hq_cache', f'{symbol}.{suffix}')
 
         fmt = TYPE_GROUP if group else None
 
         if Path(vipdoc).exists():
+            log.warning(f'找到所需的文件: {vipdoc}')
             return reader.get_df(vipdoc, fmt)
 
-        log.error(f"未找到所需的文件: {vipdoc}")
+        log.error(f'未找到所需的文件: {vipdoc}')
 
         return None
 
@@ -194,10 +198,14 @@ class ExtReader(ReaderBase):
 
         :return: pd.dataFrame or None
         """
-        vipdoc = self.find_path(symbol=symbol, subdir="lday", suffix="day")
+        vipdoc = self.find_path(symbol=symbol, subdir='lday', suffix='day')
 
-        if symbol:
-            return self.reader.get_df(vipdoc)
+        log.error(str(vipdoc))
+
+        if vipdoc:
+            from mootdx.logger import logger
+            logger.warning(vipdoc.name)
+            return self.reader.get_df(str(vipdoc))
 
         return None
 
@@ -207,10 +215,13 @@ class ExtReader(ReaderBase):
 
         :return: pd.dataFrame or None
         """
-        vipdoc = self.find_path(symbol=symbol, subdir="minline", suffix=["lc1", "1"])
+        if not symbol:
+            return None
 
-        if symbol:
-            return self.reader.get_df(vipdoc)
+        vipdoc = self.find_path(symbol=symbol, subdir='minline', suffix=['lc1', '1'])
+
+        if vipdoc:
+            return self.reader.get_df(str(vipdoc))
 
         return None
 
@@ -220,9 +231,9 @@ class ExtReader(ReaderBase):
 
         :return: pd.dataFrame or None
         """
-        vipdoc = self.find_path(symbol=symbol, subdir="fzline", suffix="lc5")
+        vipdoc = self.find_path(symbol=symbol, subdir='fzline', suffix='lc5')
 
         if symbol:
-            return self.reader.get_df(vipdoc)
+            return self.reader.get_df(str(vipdoc))
 
         return None
