@@ -1,15 +1,14 @@
-# -*- coding: utf-8 -*-
 import hashlib
 import os
 import platform
 from datetime import datetime
+from pathlib import Path
 from struct import calcsize
 from struct import unpack
 
 import pandas as pd
 from pandas import DataFrame
 from tqdm import tqdm
-from unipath import Path
 
 from mootdx.consts import MARKET_SH
 from mootdx.consts import MARKET_SZ
@@ -19,18 +18,18 @@ from mootdx.logger import log
 def get_stock_markets(symbols=None):
     results = []
 
-    assert isinstance(symbols, list), "stock code need list type"
+    assert isinstance(symbols, list), 'stock code need list type'
 
     if isinstance(symbols, list):
         for symbol in symbols:
             results.append(
-                [get_stock_market(symbol, string=False), symbol.strip("sh").strip("sz")]
+                [get_stock_market(symbol, string=False), symbol.strip('sh').strip('sz')]
             )
 
     return results
 
 
-def get_stock_market(symbol="", string=False):
+def get_stock_market(symbol='', string=False):
     """
     判断股票ID对应的证券市场匹配规则
 
@@ -43,52 +42,52 @@ def get_stock_market(symbol="", string=False):
     :return 'sh' or 'sz'
     """
 
-    assert isinstance(symbol, str), "stock code need str type"
+    assert isinstance(symbol, str), 'stock code need str type'
 
     market = None
 
-    if symbol.startswith(("sh", "sz")):
+    if symbol.startswith(('sh', 'sz')):
         market = symbol[:2]
 
-    elif symbol.startswith(("50", "51", "60", "68", "90", "110", "113", "132", "204")):
-        market = "sh"
+    elif symbol.startswith(('50', '51', '60', '68', '90', '110', '113', '132', '204')):
+        market = 'sh'
 
     elif symbol.startswith(
-        ("00", "12", "13", "18", "15", "16", "18", "20", "30", "39", "115", "1318")
+        ('00', '12', '13', '18', '15', '16', '18', '20', '30', '39', '115', '1318')
     ):
-        market = "sz"
+        market = 'sz'
 
-    elif symbol.startswith(("5", "6", "9", "7")):
-        market = "sh"
+    elif symbol.startswith(('5', '6', '9', '7')):
+        market = 'sh'
 
     if string is False:
-        market = MARKET_SZ if market == "sz" else MARKET_SH
+        market = MARKET_SZ if market == 'sz' else MARKET_SH
 
     return market
 
 
 def gpcw(filepath):
-    cw_file = open(filepath, "rb")
+    cw_file = open(filepath, 'rb')
 
-    header_size = calcsize("<3h1H3L")
-    stock_item_size = calcsize("<6s1c1L")
+    header_size = calcsize('<3h1H3L')
+    stock_item_size = calcsize('<6s1c1L')
 
     data_header = cw_file.read(header_size)
-    stock_header = unpack("<3h1H3L", data_header)
+    stock_header = unpack('<3h1H3L', data_header)
 
     max_count = stock_header[3]
 
     for idx in range(0, max_count):
-        cw_file.seek(header_size + idx * calcsize("<6s1c1L"))
+        cw_file.seek(header_size + idx * calcsize('<6s1c1L'))
         si = cw_file.read(stock_item_size)
-        stock_item = unpack("<6s1c1L", si)
+        stock_item = unpack('<6s1c1L', si)
         code = stock_item[0].decode()
         foa = stock_item[2]
         cw_file.seek(foa)
-        info_data = cw_file.read(calcsize("<264f"))
-        cw_info = unpack("<264f", info_data)
+        info_data = cw_file.read(calcsize('<264f'))
+        cw_info = unpack('<264f', info_data)
 
-        log.debug(f"{code}, {cw_info}")
+        log.debug(f'{code}, {cw_info}')
         return code, cw_info
 
 
@@ -102,10 +101,10 @@ def md5sum(downfile):
 
     try:
         md5_l = hashlib.md5()
-        md5_l.update(Path(downfile).read_file("rb"))
+        md5_l.update(Path(downfile).read_bytes())
         return md5_l.hexdigest()
     except (IOError, FileNotFoundError) as e:
-        log.error(f"无法读取文件: {downfile}")
+        log.error(f'无法读取文件: {downfile}')
         log.debug(e)
         return None
 
@@ -148,18 +147,18 @@ def to_file(df, filename=None):
         os.makedirs(path_name)
 
     extension = os.path.splitext(filename)
-    extension = extension[1] if len(extension) >= 2 else ""
+    extension = extension[1] if len(extension) >= 2 else ''
 
-    if extension == ".csv":
-        return df.to_csv(filename, encoding="utf-8", index=False)
-    elif extension == ".xlsx" or extension == ".xls":
+    if extension == '.csv':
+        return df.to_csv(filename, encoding='utf-8', index=False)
+    elif extension == '.xlsx' or extension == '.xls':
         # openpyxl, xlwt
         return df.to_excel(filename, index=False)
-    elif extension == ".h5":
+    elif extension == '.h5':
         # tables
-        return df.to_hdf(filename, "df", index=False)
-    elif extension == ".json":
-        return df.to_json(filename, orient="records")
+        return df.to_hdf(filename, 'df', index=False)
+    elif extension == '.json':
+        return df.to_json(filename, orient='records')
 
     return None
 
@@ -187,7 +186,7 @@ class TqdmUpTo(tqdm):
         self.update(downloaded - self.n)  # will also set self.n = b * bsize
 
 
-def get_config_path(config="config.json"):
+def get_config_path(config='config.json'):
     """
     获取配置文件路径
 
@@ -195,11 +194,11 @@ def get_config_path(config="config.json"):
     :return: filename
     """
 
-    sub_path = "mootdx" if platform.system() == "Windows" else ".mootdx"
-    filename = os.path.join(os.path.expanduser("~"), sub_path, config)
+    sub_path = 'mootdx' if platform.system() == 'Windows' else '.mootdx'
+    filename = os.path.join(os.path.expanduser('~'), sub_path, config)
     pathname = os.path.dirname(filename)
 
-    Path(pathname).mkdir(parents=True)
+    Path(pathname).exists() or Path(pathname).mkdir(parents=True)
 
     return filename
 
@@ -219,45 +218,45 @@ def block_new(tdxdir=None, name: str = None, symbol: list = None):
 
     # 自定义板块名称未传入则自动按时间生成名称
     if not name:
-        name = datetime.now().strftime("%Y%m%d%H%M%S")
+        name = datetime.now().strftime('%Y%m%d%H%M%S')
 
     # 按时间生成 blk 文件名
-    file = datetime.now().strftime("%Y%m%d%H%M%S")
+    file = datetime.now().strftime('%Y%m%d%H%M%S')
 
-    vipdoc = Path(tdxdir, "T0002", "blocknew")
+    vipdoc = Path(tdxdir, 'T0002', 'blocknew')
     symbol = list(set(symbol))
 
     # 判断目录是否存在
-    if not Path(vipdoc).isdir():
-        log.error(f"自定义板块目录错误: {vipdoc}")
+    if not Path(vipdoc).is_dir():
+        log.error(f'自定义板块目录错误: {vipdoc}')
         return False
 
-    block_file = Path(vipdoc, "blocknew.cfg")
+    block_file = Path(vipdoc) / 'blocknew.cfg'
 
     # 文件不存在就创建
     if not block_file.exists():
-        block_file.write_file("")
+        block_file.write_text('')
 
     # 判断名字是否重名
-    with open(block_file, "rb") as fp:
-        names = fp.read().decode("gbk", "ignore")
-        names = names.split("\x00")
-        names = [x for x in names if x != ""]
+    with open(block_file, 'rb') as fp:
+        names = fp.read().decode('gbk', 'ignore')
+        names = names.split('\x00')
+        names = [x for x in names if x != '']
         names = [v for i, v in enumerate(names) if i % 2 == 0]
 
         if name in names:
-            log.error("自定义板块名称重复.")
-            raise Exception("自定义板块名称重复.")
+            log.error('自定义板块名称重复.')
+            raise Exception('自定义板块名称重复.')
 
     # 写 blk 文件
-    with open(f"{vipdoc}/{file}.blk", "w") as fp:
-        fp.write("\n".join(symbol))
+    with open(f'{vipdoc}/{file}.blk', 'w') as fp:
+        fp.write('\n'.join(symbol))
 
     # 写 blocknew.cfg 文件
-    with open(block_file, "ab") as fp:
-        data = name + ((50 - len(name.encode("gbk", "ignore"))) * "\x00")
-        data += file + ((70 - len(file.encode("gbk", "ignore"))) * "\x00")
-        data = bytes(data.encode("gbk", "ignore"))
+    with open(block_file, 'ab') as fp:
+        data = name + ((50 - len(name.encode('gbk', 'ignore'))) * '\x00')
+        data += file + ((70 - len(file.encode('gbk', 'ignore'))) * '\x00')
+        data = bytes(data.encode('gbk', 'ignore'))
         fp.write(data)
 
     return True
